@@ -1,7 +1,7 @@
 package Test::Perinci::CmdLine;
 
 our $DATE = '2016-10-29'; # DATE
-our $VERSION = '1.42'; # VERSION
+our $VERSION = '1.43'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -23,6 +23,7 @@ our @EXPORT = (
     'pericmd_ok', # old, back-compat
     'pericmd_run_suite_ok',
     'pericmd_run_ok',
+    'pericmd_run_test_groups_ok',
 );
 
 our %SPEC;
@@ -1712,7 +1713,7 @@ Test::Perinci::CmdLine - Common test suite for Perinci::CmdLine::{Lite,Classic,I
 
 =head1 VERSION
 
-This document describes version 1.42 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2016-10-29.
+This document describes version 1.43 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2016-10-29.
 
 =for Pod::Coverage ^(pericmd_ok)$
 
@@ -1879,7 +1880,7 @@ Return value:  (any)
 
 Run groups of Perinci::CmdLine tests.
 
-This function is not exported.
+This function is exported by default.
 
 Arguments ('*' denotes required arguments):
 
